@@ -16,11 +16,14 @@ import click
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
+from osducli.commands.unit._const import (
+    UNIT_SERVICE_NAME,
+    UNIT_STATUS_PATH,
+    UNIT_SWAGGER_PATH,
+)
 from osducli.config import CONFIG_UNIT_URL
 from osducli.util.service_info import info
 
-from ._const import UNIT_SERVICE_NAME, UNIT_STATUS_PATH, UNIT_SWAGGER_PATH
-
 
 # click entry point
 @click.command(cls=CustomClickCommand)
